@@ -14,6 +14,8 @@
 #define INTERP_ICALL_TRAMP_FARGS 4
 #endif
 
+#define MAX_INTERP_ENTRY_ARGS 8
+
 struct _InterpMethodArguments {
 	size_t ilen;
 	gpointer *iargs;
@@ -21,7 +23,7 @@ struct _InterpMethodArguments {
 	double *fargs;
 	gpointer *retval;
 	size_t is_float_ret;
-#ifdef TARGET_WASM
+#ifdef TARGET_WASM // FIXME HOST
 	MonoMethodSignature *sig;
 #endif
 };
@@ -31,7 +33,8 @@ enum {
 	INTERP_OPT_INLINE = 1,
 	INTERP_OPT_CPROP = 2,
 	INTERP_OPT_SUPER_INSTRUCTIONS = 4,
-	INTERP_OPT_DEFAULT = INTERP_OPT_INLINE | INTERP_OPT_CPROP | INTERP_OPT_SUPER_INSTRUCTIONS
+	INTERP_OPT_BBLOCKS = 8,
+	INTERP_OPT_DEFAULT = INTERP_OPT_INLINE | INTERP_OPT_CPROP | INTERP_OPT_SUPER_INSTRUCTIONS | INTERP_OPT_BBLOCKS
 };
 
 typedef struct _InterpMethodArguments InterpMethodArguments;
@@ -42,4 +45,14 @@ typedef struct _InterpMethodArguments InterpMethodArguments;
  */
 MONO_API void mono_ee_interp_init (const char *);
 
+#ifdef TARGET_WASM
+
+gpointer
+mono_wasm_get_interp_to_native_trampoline (MonoMethodSignature *sig);
+
+gpointer
+mono_wasm_get_native_to_interp_trampoline (MonoMethod *method, gpointer extra_arg);
+
+#endif
+
 #endif /* __MONO_MINI_INTERPRETER_H__ */
